==> alfresco-repository-23.7.0.8-sources.jar: org/alfresco/repo/content/caching/CachingContentStoreEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.content.caching;

import org.springframework.context.ApplicationEvent;

/**
 * Abstract base class for CachingContentStore related application events.
 * 
 * @author Matt Ward
 */
public abstract class CachingContentStoreEvent extends ApplicationEvent
{
    private static final long serialVersionUID = 1L;

    /**
     * Constructor that captures the source of the event.
     * 
     * @param source
     */
    public CachingContentStoreEvent(Object source)
    {
        super(source);
    }
    
    /**
     * Is the event an instance of the specified type (or subclass)?
     * 
     * @param type {@code Class<?>}
     * @return boolean
     */
    public boolean isType(Class<?> type)
    {
        return type.isAssignableFrom(getClass());
    }
}

==> alfresco-repository-25.3.0.63-sources.jar: org/alfresco/repo/content/caching/CachingContentStoreEvent.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.content.caching;

import org.springframework.context.ApplicationEvent;

/**
 * Abstract base class for CachingContentStore related application events.
 * 
 * @author Matt Ward
 */
public abstract class CachingContentStoreEvent extends ApplicationEvent
{
    private static final long serialVersionUID = 1L;

    /**
     * Constructor that captures the source of the event.
     * 
     * @param source
     */
    public CachingContentStoreEvent(Object source)
    {
        super(source);
    }

    /**
     * Is the event an instance of the specified type (or subclass)?
     * 
     * @param type
     *            {@code Class<?>}
     * @return boolean
     */
    public boolean isType(Class<?> type)
    {
        return type.isAssignableFrom(getClass());
    }
}
